pub struct BareReport {
pub age: Duration,
pub url: String,
pub user_agent: String,
pub report_type: String,
pub body: Value,
}Expand description
Represents a single report uploaded via the Reporting API, whose body is still a JSON object and has not yet been parsed into a more specific Rust type.
Fields
age: DurationThe amount of time between when the report was generated by the user agent and when it was uploaded.
url: StringThe URL of the request that this report describes.
user_agent: StringThe value of the User-Agent header of the request that this report describes.
report_type: StringThe type of report
body: ValueThe body of the report, still encoded as a JSON object.
Implementations
Sourceimpl BareReport
impl BareReport
Sourcepub fn parse<C>(self) -> Option<Result<Report<C>, Error>>where
C: ReportType + for<'de> Deserialize<'de>,
pub fn parse<C>(self) -> Option<Result<Report<C>, Error>>where
C: ReportType + for<'de> Deserialize<'de>,
Verifies that a bare report has a particular type, and tries to parse the report body using
the corresponding Rust type. Returns Some(Ok(...)) if everything goes well. Returns
None if the report has a different type, and Some(Err(...)) if the report has the right
type but we can’t parse the report body using that type’s schema.